import { objectWithoutProperties as _objectWithoutProperties, extends as _extends } from '../../../../../_virtual/_rollupPluginBabelHelpers.js';
import { jsx } from '@emotion/core';
import React__default from 'react';
import _pt from 'prop-types';
import { baseInputCss } from '../../styles/index.esm.js';

var leftIconCss = function leftIconCss(theme) {
  return {
    position: "absolute",
    color: theme.colors.grey[60],
    fontSize: theme.fontSizes[3],
    top: "calc((100% - ".concat(theme.fontSizes[3], ") / 2)"),
    margin: "0 ".concat(theme.space[3]),
    zIndex: 2
  };
};

var inputWithLeftIconCss = function inputWithLeftIconCss(theme) {
  return {
    // offset padding based on left icon spacing and size
    paddingLeft: "calc(".concat(theme.fontSizes[3], " + 2 * ").concat(theme.space[3], ")")
  };
};

var StyledInput = React__default.forwardRef(function InputFieldControl(_ref, ref) {
  var LeftIcon = _ref.LeftIcon,
      className = _ref.className,
      props = _objectWithoutProperties(_ref, ["LeftIcon", "className"]);

  var placeholder = props.placeholder && props.disabled ? "The field is disabled" : props.placeholder;

  var baseCss = function baseCss(theme) {
    return [baseInputCss(theme), {
      width: "auto"
    }, LeftIcon && inputWithLeftIconCss(theme)];
  };

  return jsx("div", {
    className: className,
    css: {
      position: "relative"
    }
  }, LeftIcon && jsx(LeftIcon, {
    css: leftIconCss,
    size: "inherit",
    "aria-hidden": true
  }), jsx("input", _extends({
    ref: ref,
    css: baseCss
  }, props, {
    placeholder: placeholder
  })));
});
StyledInput.propTypes = {
  LeftIcon: _pt.elementType
};
StyledInput.__docgenInfo = {
  "description": "",
  "methods": [],
  "displayName": "StyledInput"
};

if (typeof STORYBOOK_REACT_CLASSES !== "undefined") {
  STORYBOOK_REACT_CLASSES["src/components/form/components/styled-primitives/StyledInput.tsx"] = {
    name: "StyledInput",
    docgenInfo: StyledInput.__docgenInfo,
    path: "src/components/form/components/styled-primitives/StyledInput.tsx"
  };
}

export { StyledInput };
//# sourceMappingURL=StyledInput.esm.js.map
